.. _why:

Why using RepRep
----------------

Before RepRep, my programs were a mess::

	|program|  --> .png, .html, .tex

Now my workflow has changed. During development, it looks like this::

	|program|  --> |reprep| -->  html for quick viewing

When I'm writing the paper, I write another program that gets the report and formats it
very carefully::

	|program|  --> |reprep| -->  |formatter| --> .tex, .png files

This has made it possible to remove all the boring messy formatting code from my programs.